@@ -41,16 +41,28 @@ DataAudio = 1  # 音频数据
 DataImage = 2  # 图像数据
 DataVideo = 3  # 视频数据
 
-DataBegin = 0 # 首数据
-DataContinue = 1 # 中间数据
-DataEnd = 2 # 尾数据
-DataOnce = 3 # 非会话单次输入输出
+Types = {
+    0: "text",
+    1: "audio",
+    2: "image",
+    3: "video"
+}
+
+DataBegin = 0  # 首数据
+DataContinue = 1  # 中间数据
+DataEnd = 2  # 尾数据
+DataOnce = 3  # 非会话单次输入输出
+
+Status = {
+    0: "begin",
+    1: "continue",
+    2: "end",
+    3: "once"
+}
 
 Once = DataOnce
 
 # 并行模式
-THREAD_MODE = "thread" # 默认模式，
-
-PROCESS_MODE = "process" # 当前不可用
-
+THREAD_MODE = "thread"  # 默认模式，
 
+PROCESS_MODE = "process"  # 当前不可用
