@@ -32,6 +32,7 @@
 #  Vestibulum commodo. Ut rhoncus gravida arcu.
 import logging
 import os
+import sys
 
 fmt = '%(asctime)s - %(name)s:%(funcName)s:%(lineno)s - %(levelname)s:  %(message)s'
 level = logging.DEBUG
@@ -60,6 +61,10 @@ def getLogger(fmt=fmt, level=level, name="root"):
 
 
 def getFileLogger(fmt=fmt, level=level, name="python_wrapper"):
+    pt = sys.platform
+    if pt.lower() == "darwin":
+        logpath = "/tmp/log/app"
+
     log = logging.getLogger(name)
     if not os.path.isdir(logpath) or not os.path.exists(logpath):
         os.makedirs(logpath)
